@@ -10,16 +10,18 @@ root = os.path.abspath(os.path.dirname(demo))
 # 先修改punittest的设置然后重载
 SETTINGS.PROJECT_ROOT = os.path.abspath(os.path.dirname(root))
 SETTINGS.RUN_TAGS = ["ALL"]
-SETTINGS.CASE_FAIL_RERUN = 2
+SETTINGS.CASE_FAIL_RERUN = 1
+SETTINGS.TEST_PREFIX = 'test'
+SETTINGS.SKIP_PREFIX = 'skip'
 
 # 如果是TEST_SET_FORM是CODE则需要指定TEST_SUITE_DIR
-SETTINGS.TEST_SUITE_DIR = os.path.join(demo, 'testsuite', 'chat')
-SETTINGS.TEST_SET_FORM = "EXCEL"
+SETTINGS.TEST_SET_FORM = "CODE"
+SETTINGS.TEST_SUITE_PATH = os.path.join(demo, 'testsuite', 'login')
 SETTINGS.TEST_EXCEL_PATH = os.path.join(root, 'excel_testset', 'TestCases.xlsx')
 
 SETTINGS.LOG_CONSOLE_SWITCH = True
 SETTINGS.LOG_FILE_SWITCH = False
-SETTINGS.LOG_REPORT_SWITCH = True
+SETTINGS.LOG_REPORT_SWITCH = False
 SETTINGS.LOG_CONSOLE_LEVEL = "DEBUG"
 SETTINGS.LOG_FILE_LEVEL = "DEBUG"
 SETTINGS.LOG_REPORT_LEVEL = "INFO"
